==> aliyun-python-sdk-oos-1.3.2.tar.gz: aliyun-python-sdk-oos-1.3.2/aliyunsdkoos/request/v20190601/GetSecretParametersRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkoos.endpoint import endpoint_data

class GetSecretParametersRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'oos', '2019-06-01', 'GetSecretParameters','oos')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_WithDecryption(self):
		return self.get_query_params().get('WithDecryption')

	def set_WithDecryption(self,WithDecryption):
		self.add_query_param('WithDecryption',WithDecryption)

	def get_Names(self):
		return self.get_query_params().get('Names')

	def set_Names(self,Names):
		self.add_query_param('Names',Names)

==> aliyun-python-sdk-oos-1.5.0.tar.gz: aliyun-python-sdk-oos-1.5.0/aliyunsdkoos/request/v20190601/GetSecretParametersRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkoos.endpoint import endpoint_data

class GetSecretParametersRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'oos', '2019-06-01', 'GetSecretParameters')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_WithDecryption(self):
		return self.get_query_params().get('WithDecryption')

	def set_WithDecryption(self,WithDecryption):
		self.add_query_param('WithDecryption',WithDecryption)

	def get_Names(self):
		return self.get_query_params().get('Names')

	def set_Names(self,Names):
		self.add_query_param('Names',Names)
